@@ -5,6 +5,7 @@ from rest_framework.views import APIView
 
 from drf_msal_jwt.exceptions import StateException
 from drf_msal_jwt.serializer import CodeSerializer
+from .settings import api_settings
 from drf_msal_jwt.utils import build_auth_url, get_user_jwt_token
 
 
@@ -29,9 +30,10 @@ class MSALLoginWithCodeView(APIView):
     permission_classes = []
 
     def post(self, request, format=None):
+        msal_check_state = api_settings.MSAL_CHECK_STATE
         code_serialized = CodeSerializer(request.data)
 
-        if request.session.get('msal_state', '') != code_serialized.data['state']:
+        if msal_check_state and request.session.get('msal_state', '') != code_serialized.data['state']:
             raise StateException()
 
         user_token = get_user_jwt_token(code_serialized.data['code'])
